@@ -31,7 +31,7 @@ STATIC_ATTRS: Tuple[str, ...] = (
     'logtype',
     'msgid', 'msgoffset',
     'event_entity', 'event_domain', 'event_action', 'event_object', 'event_service', 'event_status', 'event_subject',
-    'message')
+    'addition_msg')
 
 
 def merge_record_extra(record: logging.LogRecord, target: Dict, reserved: Union[Dict, List]) -> Dict:
@@ -234,21 +234,21 @@ class JsonFormatter(logging.Formatter):
         else:
             event_header.append(defaultval) if defaultval is not None else None
 
-    def __add_elem_in_dict_from_record(self, field, location: Dict[str, str], record: logging.LogRecord):
+    def __add_elem_in_dict_from_record(self, field, location: Dict[str, str], record: logging.LogRecord, newfieldname):
         if record.__dict__.get(field)\
                 and field not in self._skip_fields.keys():
-            location[field] = record.__dict__.get(field)
+            location[newfieldname] = record.__dict__.get(field)
 
     def create_location(self, location: Dict[str, str], record: logging.LogRecord):
         #     'location','filename', 'modulename', 'funcname', 'process', 'processName', 'thread','threadName', 'lineno',
-        self.__add_elem_in_dict_from_record('filename', location, record)
-        self.__add_elem_in_dict_from_record('modulename', location, record)
-        self.__add_elem_in_dict_from_record('funcname', location, record)
-        self.__add_elem_in_dict_from_record('process', location, record)
-        self.__add_elem_in_dict_from_record('processName', location, record)
-        self.__add_elem_in_dict_from_record('thread', location, record)
-        self.__add_elem_in_dict_from_record('threadName', location, record)
-        self.__add_elem_in_dict_from_record('lineno', location, record)
+        self.__add_elem_in_dict_from_record('filename', location, record,'file_name')
+        self.__add_elem_in_dict_from_record('modulename', location, record,'module_name')
+        self.__add_elem_in_dict_from_record('funcname', location, record,'function_name')
+        self.__add_elem_in_dict_from_record('process', location, record,'process_id')
+        self.__add_elem_in_dict_from_record('processName', location, record, 'process_name')
+        self.__add_elem_in_dict_from_record('thread', location, record, 'thread_id')
+        self.__add_elem_in_dict_from_record('threadName', location, record, 'thread_name')
+        self.__add_elem_in_dict_from_record('lineno', location, record, 'line_id')
 
     def add_msgid_and_offset_in_event_header(self, event_header: List[str], record: logging.LogRecord):
         if 'msgid' in self.static_attrs.keys():
@@ -361,7 +361,7 @@ class JsonFormatter(logging.Formatter):
             self.__add_custom_field_in_dict_from_extra_record(event_entity, extra_record)
 
         # 3. add message field
-        self.__add_field_in_log_from_record('message', event_entity, record)
+        self.__add_field_in_log_from_record('addition_msg', event_entity, record)
 
     def format(self, record: logging.LogRecord) -> str:
         """Formats a log record and serializes to json"""
